UBI: rename ubi_scan_rm_volume
The old name is not logical anymore - rename it to 'ubi_remove_av()'.
Signed-off-by: Artem Bityutskiy <artem.bityutskiy@linux.intel.com>
diff --git a/drivers/mtd/ubi/scan.c b/drivers/mtd/ubi/scan.c
index 767b857..ccf4630 100644
--- a/drivers/mtd/ubi/scan.c
+++ b/drivers/mtd/ubi/scan.c
@@ -614,11 +614,11 @@
}
/**
* ubi_scan_rm_volume - delete attaching information about a volume.
* @ai: attaching information
* @av: the volume attaching information to delete
*/
-void ubi_scan_rm_volume(struct ubi_attach_info *ai, struct ubi_ainf_volume *av)
+void ubi_remove_av(struct ubi_attach_info *ai, struct ubi_ainf_volume *av)
{
struct rb_node *rb;
struct ubi_ainf_peb *aeb;
@@ -614,11 +614,11 @@
}
/**
- * ubi_scan_rm_volume - delete attaching information about a volume.
+ * ubi_remove_av - delete attaching information about a volume.
* @ai: attaching information
* @av: the volume attaching information to delete